@@ -5,7 +5,7 @@ wald_ci <- function (x, n = 100, conf.level = 0.95,
 {
   alternative <- match.arg(alternative)
   one_or_two <- if (alternative == "two.sided") 2 else 1
-               
+  
   alpha <- 1 - conf.level
   p <- x/n
   zstar <- -qnorm(alpha/one_or_two)
@@ -38,7 +38,7 @@ plus4_ci <- function(x, n, conf.level = 0.95,
 
 agresti_ci <- function (x, n, conf.level = 0.95,
                         alternative = c("two.sided", "less", "greater") )
-                     
+  
 {
   alternative <- match.arg(alternative)
   one_or_two <- if (alternative == "two.sided") 2 else 1
@@ -60,7 +60,7 @@ agresti_ci <- function (x, n, conf.level = 0.95,
 }
 
 clopper_ci <- function(x, n, conf.level = 0.95, 
-                     alternative = c("two.sided", "less", "greater") ) 
+                       alternative = c("two.sided", "less", "greater") ) 
 {
   interval <- stats::binom.test(x, n, conf.level = conf.level, alternative = alternative)$conf.int
   attr(interval, "method") <- "Score"
@@ -90,67 +90,71 @@ score_ci <- function(x, n, conf.level = 0.95,
 #' @export
 #' @seealso [mosaic::binom.test()]
 #' 
-update_ci <- function( object, method = c("clopper-pearson", "wald", "agresti-coull", "plus4", "score", "prop.test") ) {
-  if (! inherits(object, "htest") && !grepl("^Exact binomial test", object$method) )
-    stop( "I don't know how to handle that type of object.")
-  
-  method <- match.arg(method)
-  level <- attr(object$conf.int, "conf.level") 
-  if ((level < 0.90 || level > .98) && method == "plus4")
-    warning(
-      paste("Plus 4 confidence intervals are designed for 95% confidence intervals.",
-            "Consider using another method when `conf.level` is not close to 0.95.",
-            collapse="\n")
-    )
-  
-  
-  object$conf.int <- 
-    switch(method,
-           `clopper-pearson` =  
-             clopper_ci(x = object$statistic, 
-                     n = object$parameter, 
-                     conf.level = level,
-                     alternative = object$alternative),
-           wald =  
-             wald_ci(x = object$statistic, 
-                     n = object$parameter, 
-                     conf.level = level,
-                     alternative = object$alternative),
-           plus4 = 
-             plus4_ci(x = object$statistic, 
-                      n = object$parameter, 
-                      conf.level = level,
-                      alternative = object$alternative),
-           `agresti-coull` = 
-             agresti_ci(x = object$statistic, 
+update_ci <- 
+  function(
+    object, 
+    method = c("clopper-pearson", "wald", "agresti-coull", "plus4", "score", "prop.test")
+  ) {
+    if (! inherits(object, "htest") && !grepl("^Exact binomial test", object$method) )
+      stop( "I don't know how to handle that type of object.")
+    
+    method <- match.arg(method)
+    level <- attr(object$conf.int, "conf.level") 
+    if ((level < 0.90 || level > .98) && method == "plus4")
+      warning(
+        paste("Plus 4 confidence intervals are designed for 95% confidence intervals.",
+              "Consider using another method when `conf.level` is not close to 0.95.",
+              collapse="\n")
+      )
+    
+    
+    object$conf.int <- 
+      switch(method,
+             `clopper-pearson` =  
+               clopper_ci(x = object$statistic, 
+                          n = object$parameter, 
+                          conf.level = level,
+                          alternative = object$alternative),
+             wald =  
+               wald_ci(x = object$statistic, 
+                       n = object$parameter, 
+                       conf.level = level,
+                       alternative = object$alternative),
+             plus4 = 
+               plus4_ci(x = object$statistic, 
                         n = object$parameter, 
                         conf.level = level,
                         alternative = object$alternative),
-           score = 
-             score_ci(x = object$statistic, 
-                      n = object$parameter, 
-                      conf.level = level, alternative = object$alternative,
-                      correct = FALSE),
-           wilson =   # same as score
-             score_ci(x = object$statistic, 
-                      n = object$parameter, 
-                      conf.level = level, alternative = object$alternative,
-                      correct = FALSE),
-           prop.test = # continuity correction + score
-             score_ci(x = object$statistic, 
-                      n = object$parameter, 
-                      conf.level = level, alternative = object$alternative,
-                      correct = TRUE),
-    )
-  
-  object$method <- 
-    switch(method,
-           wald = "Exact binomial test (Wald CI)",
-           plus4 = "Exact binomial test (Plus 4 CI)",
-           `agresti-coull` = "Exact binomial test (Agresti-Coull CI)",
-           score = "Exact binomial test (Score CI without continuity correction)",
-           prop.test = "Exact binomial test (Score CI with continuity correction)"
-    )
-             
-  object
-}
+             `agresti-coull` = 
+               agresti_ci(x = object$statistic, 
+                          n = object$parameter, 
+                          conf.level = level,
+                          alternative = object$alternative),
+             score = 
+               score_ci(x = object$statistic, 
+                        n = object$parameter, 
+                        conf.level = level, alternative = object$alternative,
+                        correct = FALSE),
+             wilson =   # same as score
+               score_ci(x = object$statistic, 
+                        n = object$parameter, 
+                        conf.level = level, alternative = object$alternative,
+                        correct = FALSE),
+             prop.test = # continuity correction + score
+               score_ci(x = object$statistic, 
+                        n = object$parameter, 
+                        conf.level = level, alternative = object$alternative,
+                        correct = TRUE),
+      )
+    
+    object$method <- 
+      switch(method,
+             wald = "Exact binomial test (Wald CI)",
+             plus4 = "Exact binomial test (Plus 4 CI)",
+             `agresti-coull` = "Exact binomial test (Agresti-Coull CI)",
+             score = "Exact binomial test (Score CI without continuity correction)",
+             prop.test = "Exact binomial test (Score CI with continuity correction)"
+      )
+    
+    object
+  }
