@@ -166,11 +166,11 @@ hist2freqpolygon <- function(hist) {
   brk_counts <- head(res$counts, -1) + ratio * diff(res$counts)
   
   res <-
-    dplyr::tibble(
+    tibble::tibble(
       x = c(res$mids, head(tail(res$breaks, -1), -1)), 
       density = c(res$density, brk_density),
-      counts = c(res$counts, brk_counts)) %>% 
-    arrange(x) %>% 
+      counts = c(res$counts, brk_counts)) |> 
+    arrange(x) |> 
     as.list()
   res$equidist <- hist$equidist
   res$xname <- hist$xname
