@@ -1,4 +1,4 @@
-context("as.xtabs()")
+# context("as.xtabs()")
 
 df <- data.frame( X=c('Tea','Milk'), Tea=c(3,1), Milk=c(1,3) )
 xt <- as.xtabs(df, rowvar="Guess", colvar="Truth")
@@ -12,4 +12,4 @@ testthat::test_that("as.xtabs works", {
   xt <- as.xtabs(df, rowvar="Guess", colvar="Truth")
   xt
   expect_equal(example, xt)
-})
\ No newline at end of file
+})
