@@ -1,4 +1,4 @@
-context("plotCumfreq")
+# context("plotCumfreq")
 
 testthat::test_that("plotCumfreq works", {
   wrapped_expect_doppelganger("plotCumfreq1", plotCumfreq(~eruptions, faithful, xlab = 'duration of eruptions'))
